@@ -52,8 +52,10 @@ create_window(const gchar *filename)
 
         if(filename)
                 if(!ggv_window_load(win, filename)) {
+#if 0
                         ggv_window_close(win);
                         win = NULL;
+#endif
                 }
 
         if(NULL != win) {
